import { useEffect, useState } from 'react';
import { useLocation, useNavigate } from 'react-router-dom';
import { toast } from 'sonner';
import {
  ArrowLeft,
  Heart,
  Minus,
  Plus,
  ShoppingCart,
  Star,
} from 'lucide-react';

import { useCartStore } from '@/lib/store';
import { cakeData } from '@/lib/data';

import { Button } from '@/components/ui/button';
import { Card, CardContent } from '@/components/ui/card';

export default function MenuItem() {
  const navigate = useNavigate();
  const { addToCart, initializeCart } = useCartStore();
  const [cake, setCake] = useState(null);
  const [quantity, setQuantity] = useState(1);
  const [isLoading, setIsLoading] = useState(true);

  const cakeId = useLocation().pathname.split('/')[2];

  useEffect(() => {
    initializeCart();

    // Find the cake by ID
    const foundCake = cakeData.find((c) => c.id === Number.parseInt(cakeId));
    if (foundCake) {
      setCake(foundCake);
    } else {
      // Cake not found, redirect to menu
      navigate('/menu');
      toast.error('Product Not Found', {
        description: "The cake you're looking for doesn't exist.",
      });
    }

    setIsLoading(false);
  }, [initializeCart, navigate, cakeId]);

  const handleQuantityChange = (value) => {
    if (quantity + value > 0) {
      setQuantity(quantity + value);
    }
  };

  const handleAddToCart = () => {
    if (cake) {
      addToCart({
        ...cake,
        quantity,
      });

      toast.success('Added to cart!', {
        description: `${cake.name} (${quantity}) has been added to your cart.`,
      });
    }
  };

  // Related cakes (same category)
  const relatedCakes = cake
    ? cakeData
        .filter((c) => c.category === cake.category && c.id !== cake.id)
        .slice(0, 3)
    : [];

  if (isLoading) {
    return (
      <div className='container mx-auto px-4 py-16 text-center'>
        <p>Loading product details...</p>
      </div>
    );
  }

  if (!cake) {
    return null;
  }

  return (
    <div className='container mx-auto px-4 py-8 md:py-12'>
      <Button
        variant='ghost'
        onClick={() => navigate('/menu')}
        className='mb-6 text-gray-600 hover:text-gray-800'
      >
        <ArrowLeft className='mr-2 h-4 w-4' /> Back to Menu
      </Button>

      <div className='grid grid-cols-1 md:grid-cols-2 gap-8 md:gap-16 mb-12'>
        <div className='relative h-[300px] md:h-[500px] rounded-2xl overflow-hidden'>
          <img
            src={cake.image}
            alt={cake.name}
            className='object-cover h-full w-full'
          />
          <div className='absolute top-4 right-4 bg-pink-100 text-pink-600 px-3 py-1 rounded-full text-sm font-medium'>
            {cake.category}
          </div>
        </div>

        <div className='space-y-6'>
          <div>
            <h1 className='text-3xl md:text-4xl font-bold text-gray-800 mb-2'>
              {cake.name}
            </h1>
            <div className='flex items-center mb-4'>
              <div className='flex text-yellow-400 mr-2'>
                {[...Array(5)].map((_, i) => (
                  <Star key={i} className='h-5 w-5 fill-current' />
                ))}
              </div>
              <span className='text-gray-600'>(24 reviews)</span>
            </div>
            <p className='text-2xl font-bold text-pink-600 mb-4'>
              ${cake.price.toFixed(2)}
            </p>
            <p className='text-gray-600 mb-6'>{cake.description}</p>
          </div>

          <div className='border-t border-b border-gray-200 py-6'>
            <div className='flex items-center mb-6'>
              <span className='text-gray-700 mr-4'>Quantity:</span>
              <div className='flex items-center'>
                <Button
                  variant='outline'
                  size='icon'
                  onClick={() => handleQuantityChange(-1)}
                  disabled={quantity <= 1}
                  className='h-10 w-10 rounded-full'
                >
                  <Minus className='h-4 w-4' />
                </Button>
                <span className='mx-4 text-lg font-medium w-8 text-center'>
                  {quantity}
                </span>
                <Button
                  variant='outline'
                  size='icon'
                  onClick={() => handleQuantityChange(1)}
                  className='h-10 w-10 rounded-full'
                >
                  <Plus className='h-4 w-4' />
                </Button>
              </div>
            </div>

            <div className='flex flex-col sm:flex-row gap-4'>
              <Button
                onClick={handleAddToCart}
                className='bg-pink-500 hover:bg-pink-600 text-white rounded-full py-6 flex-1'
              >
                <ShoppingCart className='mr-2 h-5 w-5' /> Add to Cart
              </Button>
              <Button
                variant='outline'
                className='border-pink-300 text-pink-600 hover:bg-pink-50 rounded-full py-6'
              >
                <Heart className='mr-2 h-5 w-5' /> Add to Wishlist
              </Button>
            </div>
          </div>

          <div className='space-y-4'>
            <h3 className='text-lg font-semibold text-gray-800'>
              Product Details
            </h3>
            <div className='grid grid-cols-2 gap-4'>
              <div>
                <p className='text-gray-600 font-medium'>Category</p>
                <p className='text-gray-800'>{cake.category}</p>
              </div>
              <div>
                <p className='text-gray-600 font-medium'>Serves</p>
                <p className='text-gray-800'>8-10 people</p>
              </div>
              <div>
                <p className='text-gray-600 font-medium'>Allergens</p>
                <p className='text-gray-800'>Eggs, Dairy, Wheat</p>
              </div>
              <div>
                <p className='text-gray-600 font-medium'>Storage</p>
                <p className='text-gray-800'>Refrigerate</p>
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* Related Products */}
      {relatedCakes.length > 0 && (
        <div className='mt-16'>
          <h2 className='text-2xl font-bold text-gray-800 mb-6'>
            You May Also Like
          </h2>
          <div className='grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-6'>
            {relatedCakes.map((relatedCake) => (
              <Card
                key={relatedCake.id}
                className='overflow-hidden shadow-sm transition-transform hover:scale-105 hover:shadow-md'
              >
                <div className='relative h-56'>
                  <img
                    src={relatedCake.image}
                    alt={relatedCake.name}
                    className='object-cover h-full w-full'
                  />
                </div>
                <CardContent className='p-6'>
                  <div className='flex justify-between items-start mb-2'>
                    <h3 className='text-xl font-semibold text-gray-800'>
                      {relatedCake.name}
                    </h3>
                    <p className='text-pink-600 font-bold'>
                      ${relatedCake.price.toFixed(2)}
                    </p>
                  </div>
                  <p className='text-gray-600 mb-4 line-clamp-2'>
                    {relatedCake.description}
                  </p>
                  <Button
                    onClick={() => navigate(`/menu/${relatedCake.id}`)}
                    className='w-full bg-yellow-100 hover:bg-yellow-200 text-yellow-800 rounded-full'
                  >
                    View Details
                  </Button>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      )}
    </div>
  );
}
